@@ -37,7 +37,7 @@ CEMBA_SNM3C_L4REGION_COOL_DS_PATH_LIST = [f'/cemba/m3c-CoolDS/group{i}.coolds' f
 CEMBA_SNM3C_L4REGION_COOL_DS_SAMPLE_WEIGHTS_PATH = '/cemba/m3c-CoolDS/CEMBA.snm3C.L4Region.CellCounts.csv'
 CEMBA_SNM3C_L4REGION_COOL_DS_CHROMS_SIZES_PATH = '/cemba/m3c-CoolDS/mm10.main.nochrY.nochrM.chrom.sizes'
 CEMBA_SNM3C_L4REGION_CHROM_25K_COOL_DS_PATH = '/cemba/CEMBA_3C/CEMBA.snm3C.chrom25k.L4Region.Q.coolds'
-CEMBA_SNM3C_L4REGION_CHROM_100K_COOL_DS_PATH = 'CEMBA.snm3C.chrom100k.L4Region.Q+Raw.coolds'
+CEMBA_SNM3C_L4REGION_CHROM_100K_COOL_DS_PATH = '/cemba/CEMBA_3C/CEMBA.snm3C.chrom100k.L4Region.Q+Raw.coolds'
 
 
 # MCDS Path 04/20/2022
